-- This Macaulay2 code can be used to determine the coefficients \chi

restart
-- d = 4, all chi vectors
R = QQ[x,y,z,w]

delta := product {(x-y), (x-z), (x-w), (y-z), (y-w), (z-w)}

psiN = n -> (
    g = gens R;
    sum ((x -> x^n) \ g))
    
psiRho = r -> (
    rho := select (r, (rr -> rr =!= 0));
    product (psiN \ rho))

coeffs = (mu, rho) -> (
    -- rho can be a partition or a list
    rhorho := toList rho;
    mumu := toList mu;
    while (#mumu < 4) do mumu = mumu | {0};
    p := delta * psiRho rhorho;
    coefficient (x^(mumu#0+3)*y^(mumu#1+2)*z^(mumu#2+1)*w^(mumu#3), p))

-- Resulting coefficient vectors for d = 4
chi4 = coeffs_({4}) \ (partitions (4))
chi31 = coeffs_({3,1}) \ (partitions (4))
chi22 = coeffs_({2,2}) \ (partitions (4))
chi211 = coeffs_({2,1,1}) \ (partitions (4))
chi1111 = coeffs_({1,1,1,1}) \ (partitions (4))



-- d = 5, all chi vectors
S = QQ[a,b,c,d,e]

delta := product flatten for i from 0 to 4 list (
    for j from i+1 to 4 list (
	(gens S)#i - (gens S)#j))

psiN = n -> (
    g = gens S;
    sum ((x -> x^n) \ g))
    
psiRho = r -> (
    rho := select (r, (rr -> rr =!= 0));
    product (psiN \ r))

coeffs = (mu, rho) -> (
    -- mu can be a partition or a list
    mumu := toList mu;
    rhorho := toList rho;
    while (#mumu < 5) do mumu = mumu | {0};
    p := delta * psiRho rhorho;
    coefficient (a^(mumu#0+4)*b^(mumu#1+3)*c^(mumu#2+2)*d^(mumu#3+1)*e^(mumu#4), p))

-- Resulting coefficient vectors for d = 4
chi5 = coeffs_({5}) \ (partitions (5))
chi41 = coeffs_({4,1}) \ (partitions (5))
chi32 = coeffs_({3,2}) \ (partitions (5))
chi311 = coeffs_({3,1,1}) \ (partitions (5))
chi221 = coeffs_({2,2,1}) \ (partitions (5))
chi2111 = coeffs_({2,1,1,1}) \ (partitions (5))
chi11111 = coeffs_({1,1,1,1,1}) \ (partitions (5))

